@@ -4,8 +4,8 @@ Last Change Author: Paul Côté
 Last Date Changed: 2022/09/07
 """
 
-import laniakea_plugin_sdk.proto.plugin_pb2 as plugin_pb2
-import laniakea_plugin_sdk.proto.plugin_pb2_grpc as plugin_pb2_grpc
+import src.laniakea_plugin_sdk.proto.plugin_pb2 as plugin_pb2
+import src.laniakea_plugin_sdk.proto.plugin_pb2_grpc as plugin_pb2_grpc
 
 from concurrent import futures
 import grpc
@@ -37,7 +37,7 @@ class ControllerBase(plugin_pb2_grpc.ControllerServicer):
     def GetVersion(self, request, context):
         if not self.version:
             raise ValueError("plugin version not set")
-        return self.version
+        return plugin_pb2.VersionNumber(version=self.version)
 
     def PushVersion(self, request, context):
         laniV = version.parse(request.version)
