@@ -4,8 +4,8 @@ Last Change Author: Paul Côté
 Last Date Changed: 2022/09/07
 """
 
-import laniakea_plugin_sdk.proto.plugin_pb2 as plugin_pb2
-import laniakea_plugin_sdk.proto.plugin_pb2_grpc as plugin_pb2_grpc
+import src.laniakea_plugin_sdk.proto.plugin_pb2 as plugin_pb2
+import src.laniakea_plugin_sdk.proto.plugin_pb2_grpc as plugin_pb2_grpc
 
 from concurrent import futures
 import grpc
